import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { O as OAuthApp, U as UpdateOAuthApp, a as OAuthAppsQueryBuilder, b as OAuthAppCreatedEnvelope, c as OAuthAppDeletedEnvelope, d as OAuthAppUpdatedEnvelope } from './headless-v1-o-auth-app-o-auth-apps.universal-BxqhS2nh.js';
export { ac as ActionEvent, A as Asset, ag as BaseEventMetadata, C as CreateOAuthAppRequest, j as CreateOAuthAppResponse, s as CursorPaging, v as Cursors, F as DeleteContext, n as DeleteOAuthAppRequest, o as DeleteOAuthAppResponse, D as DeleteStatus, a6 as DomainEvent, a7 as DomainEventBodyOneOf, a5 as Empty, a8 as EntityCreatedEvent, ab as EntityDeletedEvent, aa as EntityUpdatedEvent, ah as EventMetadata, w as GenerateOAuthAppSecretRequest, x as GenerateOAuthAppSecretResponse, G as GetOAuthAppRequest, k as GetOAuthAppResponse, ae as IdentificationData, af as IdentificationDataIdOneOf, ad as MessageEnvelope, M as MetaSiteSpecialEvent, y as MetaSiteSpecialEventPayloadOneOf, N as Namespace, Y as NamespaceChanged, e as OAuthAppType, ai as OAuthAppsQueryResult, f as OAuthTechnologies, a1 as OdeditorAssigned, a2 as OdeditorUnassigned, r as Paging, u as PagingMetadataV2, a3 as PicassoAssigned, a4 as PicassoUnassigned, P as PlatformQuery, p as PlatformQueryPagingMethodOneOf, Q as QueryOAuthAppsRequest, t as QueryOAuthAppsResponse, a9 as RestoreInfo, R as ServiceProvisioned, T as ServiceRemoved, z as SiteCreated, h as SiteCreatedContext, E as SiteDeleted, X as SiteHardDeleted, K as SiteMarkedAsTemplate, L as SiteMarkedAsWixSite, I as SitePublished, a0 as SitePurgedExternally, V as SiteRenamed, B as SiteTransferred, H as SiteUndeleted, J as SiteUnpublished, $ as SiteUrlChanged, S as SortOrder, q as Sorting, g as State, Z as StudioAssigned, _ as StudioUnassigned, l as UpdateOAuthAppRequest, m as UpdateOAuthAppResponse, W as WebhookIdentityType, i as WixPagesDomainMapping } from './headless-v1-o-auth-app-o-auth-apps.universal-BxqhS2nh.js';

declare function createOAuthApp$1(httpClient: HttpClient): CreateOAuthAppSignature;
interface CreateOAuthAppSignature {
    /**
     * Creates a new OAuth app for a Wix Headless client.
     *
     * Use this API to enable headless functionality for a Wix site. An OAuth app allows external sites or apps to securely access your site's data and services using Wix APIs.
     * @param - OAuth app to create.
     * @returns Created OAuth app info.
     */
    (oAuthApp: OAuthApp): Promise<OAuthApp>;
}
declare function getOAuthApp$1(httpClient: HttpClient): GetOAuthAppSignature;
interface GetOAuthAppSignature {
    /**
     * Retrieves an OAuth app by ID.
     * @param - ID of the OAuth app to retrieve.
     * @returns Retrieved OAuth app info.
     */
    (oAuthAppId: string): Promise<OAuthApp>;
}
declare function updateOAuthApp$1(httpClient: HttpClient): UpdateOAuthAppSignature;
interface UpdateOAuthAppSignature {
    /**
     * Updates an OAuth app.
     *
     *
     * Only fields provided in `mask.paths` are updated.
     *
     * You can update the following fields:
     * + `name`
     * + `description`
     * + `allowedDomain`
     * + `loginUrl`
     * + `logoutUrl`
     * + `technology`
     * @param - ID of the OAuth app.
     * @param - Explicit list of fields to update. Only fields listed are updated.
     * @returns Updated OAuth app info.
     */
    (_id: string, oAuthApp: UpdateOAuthApp, mask: string[]): Promise<OAuthApp>;
}
declare function queryOAuthApps$1(httpClient: HttpClient): QueryOAuthAppsSignature;
interface QueryOAuthAppsSignature {
    /**
     * Retrieves a list of OAuth apps, given the provided paging, filtering, and sorting.
     *
     *
     * Query OAuth Apps runs with these defaults, which you can override:
     * + Results are sorted by `id` in descending order.
     * + `paging.offset` is `0`.
     */
    (): OAuthAppsQueryBuilder;
}
declare const onOAuthAppCreated$1: EventDefinition<OAuthAppCreatedEnvelope, "wix.headless.v1.o_auth_app_created">;
declare const onOAuthAppDeleted$1: EventDefinition<OAuthAppDeletedEnvelope, "wix.headless.v1.o_auth_app_deleted">;
declare const onOAuthAppUpdated$1: EventDefinition<OAuthAppUpdatedEnvelope, "wix.headless.v1.o_auth_app_updated">;

declare const createOAuthApp: MaybeContext<BuildRESTFunction<typeof createOAuthApp$1> & typeof createOAuthApp$1>;
declare const getOAuthApp: MaybeContext<BuildRESTFunction<typeof getOAuthApp$1> & typeof getOAuthApp$1>;
declare const updateOAuthApp: MaybeContext<BuildRESTFunction<typeof updateOAuthApp$1> & typeof updateOAuthApp$1>;
declare const queryOAuthApps: MaybeContext<BuildRESTFunction<typeof queryOAuthApps$1> & typeof queryOAuthApps$1>;
/**
 * Triggered when an OAuth app is created.
 */
declare const onOAuthAppCreated: BuildEventDefinition<typeof onOAuthAppCreated$1>;
/**
 * Triggered when an OAuth app is deleted.
 */
declare const onOAuthAppDeleted: BuildEventDefinition<typeof onOAuthAppDeleted$1>;
/**
 * Triggered when an OAuth app is updated.
 */
declare const onOAuthAppUpdated: BuildEventDefinition<typeof onOAuthAppUpdated$1>;

export { OAuthApp, OAuthAppCreatedEnvelope, OAuthAppDeletedEnvelope, OAuthAppUpdatedEnvelope, OAuthAppsQueryBuilder, UpdateOAuthApp, createOAuthApp, getOAuthApp, onOAuthAppCreated, onOAuthAppDeleted, onOAuthAppUpdated, queryOAuthApps, updateOAuthApp };
