import { C as CreateOAuthAppRequest$1, j as CreateOAuthAppResponse$1, k as GetOAuthAppRequest$1, l as GetOAuthAppResponse$1, m as UpdateOAuthAppRequest$1, n as UpdateOAuthAppResponse$1, o as DeleteOAuthAppRequest$1, p as DeleteOAuthAppResponse$1, Q as QueryOAuthAppsRequest$1, u as QueryOAuthAppsResponse$1, x as GenerateOAuthAppSecretRequest$1, G as GenerateOAuthAppSecretResponse$1 } from './headless-v1-o-auth-app-o-auth-apps.universal-CGWo2AKQ.js';

/** An intermediary application that authorizes and authenticates an external client to access data on a Wix project or site. */
interface OAuthApp {
    /**
     * ID of the OAuth app.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Date and time the OAuth app was created, in ISO 8601 format.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Display name of the OAuth app, as it appears in the dashboard.
     * @minLength 2
     * @maxLength 256
     */
    name?: string | null;
    /** Description of the OAuth app, as it appears in the dashboard. */
    description?: string | null;
    /**
     * For internal use only.
     * @readonly
     * @deprecated
     */
    secret?: string | null;
    /**
     * External login URL to which users are redirected automatically to authenticate. If no login URL is specified, the user is redirected to Wix to authenticate.
     * @format WEB_URL
     */
    loginUrl?: string | null;
    /**
     * List of URIs to which redirection from Wix is allowed after authentication.
     *
     * When a client redirects a user to Wix for authentication, the client provides a URI to redirect the user back to after the user has been authenticated.
     * Wix only redirects the user if the exact URI is contained in this array.
     * @format URI
     * @maxSize 10
     */
    allowedRedirectUris?: string[];
    /**
     * List of domains to which redirection from Wix is allowed after processes other than authentication.
     *
     * When a client redirects a user to a Wix page (for example, for checkout), the client provides a URL to redirect the user back to.
     * Wix only redirects the user if the URL is in one of the specified domains.
     * @maxSize 10
     */
    allowedRedirectDomains?: string[];
    /** For internal use only. */
    allowSecretGeneration?: boolean | null;
    /**
     * External logout URL to which we invoke when user logout at wix. If no logout URL is specified, the user is logged out only at Wix.
     * @format WEB_URL
     */
    logoutUrl?: string | null;
    /** OAuth application type. */
    applicationType?: OAuthAppTypeWithLiterals;
    /** OAuth technology used by the oauth application. */
    technology?: OAuthTechnologiesWithLiterals;
    /**
     * List of domain mappings from external domains to Wix domains.
     * When a user accesses a non-Wix domain, they can be automatically forwarded to the corresponding
     * Wix domain based on these mappings. This enables domain-level redirection from
     * external domains to Wix-hosted pages.
     * @maxSize 10
     */
    wixPagesDomainsMappings?: WixPagesDomainMapping[];
}
/** OAuth application type. */
declare enum OAuthAppType {
    /** OAuth app type is not specified. */
    OAUTH_APP_TYPE_UNSPECIFIED = "OAUTH_APP_TYPE_UNSPECIFIED",
    /** OAuth app type is a web application. */
    WEB_APP = "WEB_APP",
    /** OAuth app type is a mobile application. */
    MOBILE = "MOBILE",
    /** OAuth app type is some other type of application. */
    OTHER = "OTHER"
}
/** @enumType */
type OAuthAppTypeWithLiterals = OAuthAppType | 'OAUTH_APP_TYPE_UNSPECIFIED' | 'WEB_APP' | 'MOBILE' | 'OTHER';
/** OAuth technology used by the oauth application. */
declare enum OAuthTechnologies {
    /** The OAuth technology is not specified. */
    OAUTH_TECHNOLOGY_UNSPECIFIED = "OAUTH_TECHNOLOGY_UNSPECIFIED",
    /** OAuth technology using JavaScript. */
    JAVASCRIPT = "JAVASCRIPT",
    /** OAuth technology using Angular. */
    ANGULAR = "ANGULAR",
    /** OAuth technology using Vue.js. */
    VUE = "VUE",
    /** OAuth technology using React. */
    REACT = "REACT",
    /** OAuth technology using React Native. */
    REACT_NATIVE = "REACT_NATIVE",
    /** OAuth technology using iOS. */
    IOS = "IOS",
    /** OAuth technology using Android. */
    ANDROID = "ANDROID",
    /** OAuth technology using some other kind of technology. */
    OTHER_TECHNOLOGY = "OTHER_TECHNOLOGY"
}
/** @enumType */
type OAuthTechnologiesWithLiterals = OAuthTechnologies | 'OAUTH_TECHNOLOGY_UNSPECIFIED' | 'JAVASCRIPT' | 'ANGULAR' | 'VUE' | 'REACT' | 'REACT_NATIVE' | 'IOS' | 'ANDROID' | 'OTHER_TECHNOLOGY';
interface WixPagesDomainMapping {
    /** @maxLength 2048 */
    origin?: string;
    /** @maxLength 2048 */
    destination?: string;
}
interface CreateOAuthAppRequest {
    /** OAuth app to create. */
    oAuthApp: OAuthApp;
}
interface CreateOAuthAppResponse {
    /** Created OAuth app info. */
    oAuthApp?: OAuthApp;
}
interface GetOAuthAppRequest {
    /**
     * ID of the OAuth app to retrieve.
     * @format GUID
     */
    oAuthAppId: string;
}
interface GetOAuthAppResponse {
    /** Retrieved OAuth app info. */
    oAuthApp?: OAuthApp;
}
interface UpdateOAuthAppRequest {
    /** Updated OAuth app details. May include some or all fields. */
    oAuthApp: OAuthApp;
    /** Explicit list of fields to update. Only fields listed are updated. */
    mask?: string[];
}
interface UpdateOAuthAppResponse {
    /** Updated OAuth app info. */
    oAuthApp?: OAuthApp;
}
interface DeleteOAuthAppRequest {
    /**
     * ID of the OAuth app to delete.
     * @format GUID
     */
    oAuthAppId: string;
}
interface DeleteOAuthAppResponse {
}
interface QueryOAuthAppsRequest {
    /** Query options. */
    query?: PlatformQuery;
}
interface PlatformQuery extends PlatformQueryPagingMethodOneOf {
    /** Paging options to limit and skip the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"name","order":"ASC"},{"fieldName":"created_date","order":"DESC"}]`
     * @maxSize 3
     */
    sort?: Sorting[];
}
/** @oneof */
interface PlatformQueryPagingMethodOneOf {
    /** Paging options to limit and skip the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface QueryOAuthAppsResponse {
    /** List of OAuth apps matching the query. */
    oAuthApps?: OAuthApp[];
    /** Paging metadata. */
    pagingMetadata?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface GenerateOAuthAppSecretRequest {
    /**
     * ID of the OAuth app to generate a secret for.
     * @format GUID
     */
    oAuthAppId: string;
}
interface GenerateOAuthAppSecretResponse {
    /** Secret generated. */
    oAuthAppSecret?: string;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function createOAuthApp(): __PublicMethodMetaInfo<'POST', {}, CreateOAuthAppRequest$1, CreateOAuthAppRequest, CreateOAuthAppResponse$1, CreateOAuthAppResponse>;
declare function getOAuthApp(): __PublicMethodMetaInfo<'GET', {
    oAuthAppId: string;
}, GetOAuthAppRequest$1, GetOAuthAppRequest, GetOAuthAppResponse$1, GetOAuthAppResponse>;
declare function updateOAuthApp(): __PublicMethodMetaInfo<'PATCH', {
    oAuthAppId: string;
}, UpdateOAuthAppRequest$1, UpdateOAuthAppRequest, UpdateOAuthAppResponse$1, UpdateOAuthAppResponse>;
declare function deleteOAuthApp(): __PublicMethodMetaInfo<'DELETE', {
    oAuthAppId: string;
}, DeleteOAuthAppRequest$1, DeleteOAuthAppRequest, DeleteOAuthAppResponse$1, DeleteOAuthAppResponse>;
declare function queryOAuthApps(): __PublicMethodMetaInfo<'POST', {}, QueryOAuthAppsRequest$1, QueryOAuthAppsRequest, QueryOAuthAppsResponse$1, QueryOAuthAppsResponse>;
declare function generateOAuthAppSecret(): __PublicMethodMetaInfo<'POST', {
    oAuthAppId: string;
}, GenerateOAuthAppSecretRequest$1, GenerateOAuthAppSecretRequest, GenerateOAuthAppSecretResponse$1, GenerateOAuthAppSecretResponse>;

export { type __PublicMethodMetaInfo, createOAuthApp, deleteOAuthApp, generateOAuthAppSecret, getOAuthApp, queryOAuthApps, updateOAuthApp };
