// src/headless-v1-o-auth-app-o-auth-apps.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformSDKFieldMaskToRESTFieldMask } from "@wix/sdk-runtime/transformations/field-mask";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveWixHeadlessV1OAuthAppServiceUrl(opts) {
  const domainToMappings = {
    "manage._base_domain_": [
      {
        srcPath: "/oauth-app-service",
        destPath: ""
      },
      {
        srcPath: "/oauth-app",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/oauth-app",
        destPath: ""
      }
    ],
    "api._api_base_domain_": [
      {
        srcPath: "/oauth-app-service",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_auth-management_o-auth-apps";
function createOAuthApp(payload) {
  function __createOAuthApp({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [{ path: "oAuthApp.createdDate" }]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.headless.v1.o_auth_app",
      method: "POST",
      methodFqn: "wix.headless.v1.OAuthAppService.CreateOAuthApp",
      packageName: PACKAGE_NAME,
      url: resolveWixHeadlessV1OAuthAppServiceUrl({
        protoPath: "/v1/oauth-apps",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [{ path: "oAuthApp.createdDate" }]
        }
      ])
    };
    return metadata;
  }
  return __createOAuthApp;
}
function getOAuthApp(payload) {
  function __getOAuthApp({ host }) {
    const metadata = {
      entityFqdn: "wix.headless.v1.o_auth_app",
      method: "GET",
      methodFqn: "wix.headless.v1.OAuthAppService.GetOAuthApp",
      packageName: PACKAGE_NAME,
      url: resolveWixHeadlessV1OAuthAppServiceUrl({
        protoPath: "/v1/oauth-apps/{oAuthAppId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [{ path: "oAuthApp.createdDate" }]
        }
      ])
    };
    return metadata;
  }
  return __getOAuthApp;
}
function updateOAuthApp(payload) {
  function __updateOAuthApp({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "mask" }]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [{ path: "oAuthApp.createdDate" }]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.headless.v1.o_auth_app",
      method: "PATCH",
      methodFqn: "wix.headless.v1.OAuthAppService.UpdateOAuthApp",
      packageName: PACKAGE_NAME,
      url: resolveWixHeadlessV1OAuthAppServiceUrl({
        protoPath: "/v1/oauth-apps/{oAuthApp.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [{ path: "oAuthApp.createdDate" }]
        }
      ])
    };
    return metadata;
  }
  return __updateOAuthApp;
}
function deleteOAuthApp(payload) {
  function __deleteOAuthApp({ host }) {
    const metadata = {
      entityFqdn: "wix.headless.v1.o_auth_app",
      method: "DELETE",
      methodFqn: "wix.headless.v1.OAuthAppService.DeleteOAuthApp",
      packageName: PACKAGE_NAME,
      url: resolveWixHeadlessV1OAuthAppServiceUrl({
        protoPath: "/v1/oauth-apps/{oAuthAppId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteOAuthApp;
}
function queryOAuthApps(payload) {
  function __queryOAuthApps({ host }) {
    const metadata = {
      entityFqdn: "wix.headless.v1.o_auth_app",
      method: "POST",
      methodFqn: "wix.headless.v1.OAuthAppService.QueryOAuthApps",
      packageName: PACKAGE_NAME,
      url: resolveWixHeadlessV1OAuthAppServiceUrl({
        protoPath: "/v1/oauth-apps/query",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [{ path: "oAuthApps.createdDate" }]
        }
      ])
    };
    return metadata;
  }
  return __queryOAuthApps;
}
function generateOAuthAppSecret(payload) {
  function __generateOAuthAppSecret({ host }) {
    const metadata = {
      entityFqdn: "wix.headless.v1.o_auth_app",
      method: "POST",
      methodFqn: "wix.headless.v1.OAuthAppService.GenerateOAuthAppSecret",
      packageName: PACKAGE_NAME,
      url: resolveWixHeadlessV1OAuthAppServiceUrl({
        protoPath: "/v1/oauth-apps/{oAuthAppId}/generate-secret",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __generateOAuthAppSecret;
}

// src/headless-v1-o-auth-app-o-auth-apps.meta.ts
function createOAuthApp2() {
  const payload = {};
  const getRequestOptions = createOAuthApp(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/oauth-apps",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function getOAuthApp2() {
  const payload = { oAuthAppId: ":oAuthAppId" };
  const getRequestOptions = getOAuthApp(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v1/oauth-apps/{oAuthAppId}",
    pathParams: { oAuthAppId: "oAuthAppId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function updateOAuthApp2() {
  const payload = { oAuthApp: { id: ":oAuthAppId" } };
  const getRequestOptions = updateOAuthApp(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PATCH",
    path: "/v1/oauth-apps/{oAuthApp.id}",
    pathParams: { oAuthAppId: "oAuthAppId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function deleteOAuthApp2() {
  const payload = { oAuthAppId: ":oAuthAppId" };
  const getRequestOptions = deleteOAuthApp(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "DELETE",
    path: "/v1/oauth-apps/{oAuthAppId}",
    pathParams: { oAuthAppId: "oAuthAppId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function queryOAuthApps2() {
  const payload = {};
  const getRequestOptions = queryOAuthApps(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/oauth-apps/query",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function generateOAuthAppSecret2() {
  const payload = { oAuthAppId: ":oAuthAppId" };
  const getRequestOptions = generateOAuthAppSecret(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/oauth-apps/{oAuthAppId}/generate-secret",
    pathParams: { oAuthAppId: "oAuthAppId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
export {
  createOAuthApp2 as createOAuthApp,
  deleteOAuthApp2 as deleteOAuthApp,
  generateOAuthAppSecret2 as generateOAuthAppSecret,
  getOAuthApp2 as getOAuthApp,
  queryOAuthApps2 as queryOAuthApps,
  updateOAuthApp2 as updateOAuthApp
};
//# sourceMappingURL=meta.mjs.map